/*
  Copyright (C) 1997,1998  Dimitrios P. Bouras

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   For author contact information, look in the README file.
*/

/* PPP networking utility routines */

char *IFAddr(char *, int);	/* get IF source or destination address */
char *pppAddr(char *);		/* if PPP IF active, returns IP address string */
unsigned pppPkts(char *,	/* returns sum of TX and RX packets on IF, and */
	unsigned long*,			/* if storage specified, TX/RX in separate vars */
	unsigned long *);

